# -*- coding: utf-8 -*-
"""
web2ldap plugin classes for attributes defined for msPerson

$Id: msperson.py,v 1.8 2011/10/19 07:50:05 michael Exp $
"""

import re,os.path,time,pyweblib.forms, \
       web2ldapcnf

from w2lapp.schema.syntaxes import LDAPSyntax,Boolean,DirectoryString, \
  Integer,IA5String,PropertiesSelectList,ISO8601Date,syntax_registry


class Gender(PropertiesSelectList):
  oid = 'Gender-oid'
  desc = 'Representation of human sex (see ISO 5218)'
  properties_pathname = os.path.join(web2ldapcnf.etc_dir,os.path.join('web2ldap','properties','attribute_select_gender.properties'))

syntax_registry.registerAttrType(
  Gender.oid,[
    '1.3.6.1.4.1.5427.1.389.4.7', # gender (defined for msPerson)
  ]
)


class DateOfBirth(ISO8601Date):
  oid = 'DateOfBirth-oid'
  desc = 'Date of birth: syntax YYYY-MM-DD, see ISO 8601'

syntax_registry.registerAttrType(
  DateOfBirth.oid,[
    '1.3.6.1.4.1.5427.1.389.4.2', # dateOfBirth
  ]
)


class LabeledBICandIBAN(DirectoryString):
  """
  More information:
  http://de.wikipedia.org/wiki/International_Bank_Account_Number
  http://www.pruefziffernberechnung.de/I/IBAN.shtml
  """
  oid = 'LabeledBICandIBAN-oid'
  desc = 'International bank account number (IBAN) syntax (see ISO 13616:1997)'

syntax_registry.registerAttrType(
  LabeledBICandIBAN.oid,[
    '1.3.6.1.4.1.5427.1.389.4.13', # labeledBICandIBAN
  ]
)


# Register all syntax classes in this module
for name in dir():
  syntax_registry.registerSyntaxClass(eval(name))

